==> upd-2.0-32.tgz: home/hadmin/html/misc/advanced.php <==
<?PHP
/* $Id: advanced.php,v 1.20 2001/04/26 11:12:51 bzizou Exp $
Advanced functions menu

This script is part of the SLIS Project initiated by the CARMI-Internet
(Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet
(Acadmie de Grenoble - France 38).

This script have been writen by Bruno Bzeznik - copyright (C) 2001
Ce script  t crit par Bruno Bzeznik - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire.
Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License
along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail
to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  <slis@ac-grenoble.fr>
*/

// loading libs
require("../inc/html.inc.php");
require("../inc/lib.inc.php");

print startHTML("Advanced");

// The menu is different if there is only one network interface
if (n_interfaces() > 2) { $one_interface_menu=1;}

stop_if_no_admin();

// Prepare the menu
$text  = "<BR><FONT FACE=Helvetica,Arial>\n<UL><B>";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Administration</FONT>\n<UL>\n";
$text .= menu_item("../admin/administrator.php",$lang_adv_Admin_params,0,0);
$text .= menu_item("/cgi-bin/etrn.cgi",$lang_adv_Mailqueue,0,0);
$text .= menu_item("cancel.php?mode=view",$lang_adv_View,0,0);
$text .= menu_item("../admin/live_update.php",$lang_adv_Update,0,0);
$text .= menu_item("../admin/ups.php",$lang_adv_UPS,0,0);
if (file_exists("/etc/adsl")) {
  $text .= menu_item("../adsl/adsl-index.php",$lang_adv_ADSL,1,0);
}
if ($VTUN=="1") {
  $text .= menu_item("../admin/tunnel.php",$lang_adv_Tunnel,0,0);
}
$text .= menu_item("../admin/backup.php?action=wait",$lang_adv_Backup,0,0);
$text .= menu_item("../admin/shutdown.php",$lang_adv_Shutdown,0,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Web</FONT>\n<UL>\n";
$text .= menu_item("/cgi-bin/web_nom_webmaster_form.cgi",$lang_adv_Webmaster,0,0);
$text .= menu_item("../web/replication.php?action=index",$lang_adv_Push,0,0);
$text .= menu_item("../web/get.php?action=index",$lang_adv_Get,0,0);
$text .= menu_item("../baseweb.php",$lang_adv_DBweb,1,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Diags</FONT>\n<UL>\n";
$text .= menu_item("../diags/info.php",$lang_adv_Infos,0,0);
$text .= menu_item("../diags/stats.php?action=index",$lang_adv_Statsconn,0,0);
#$text .= menu_item("../prostat",$lang_adv_Proxy,0,0);
$text .= menu_item("../diags/ping.php",$lang_adv_Ping,0,0);
$text .= menu_item("../diags/df.php",$lang_adv_Disk,0,0);
$text .= menu_item("/cgi-bin/mail_watch_form.cgi",$lang_adv_Headers,0,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Secu</FONT>\n<UL>\n";
$text .= menu_item("/cgi-bin/subnets_act.cgi",$lang_adv_Access,0,1);
$text .= menu_item("/cgi-bin/niveaux_secu.cgi",$lang_adv_IP_filters,0,1);
$text .= menu_item("/cgi-bin/squidguard_form.cgi",$lang_adv_URL_filters,0,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Lan</FONT>\n<UL>\n";
$text .= menu_item("../lan/vnc.php?action=index",$lang_adv_VNC,0,0);
$text .= menu_item("../dhcp",$lang_adv_DHCP,1,0);
$text .= "</B></UL><P></UL>\n";
if ($experimental_menu!=1) {
  $text .= "<HR><CENTER><A HREF=./advanced.php?experimental_menu=1>$lang_adv_Exp</A></CENTER><P>\n";
}
else {
  $text .= "<HR><CENTER><A HREF=./advanced.php?experimental_menu=0>$lang_adv_Normal</A></CENTER><P>\n";
  $exp=" <I>(experimental)</I>";
}
$text .= "</FONT><BR>\n";

// print the menu
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv . $exp,$titre_color);
$val = center($val);
$val = saut(2)."$val";
print "$val\n";      

// The end
print endHTML();

?>

==> upd-2.0-37.tgz: home/hadmin/html/misc/advanced.php <==
<?PHP
/* $Id: advanced.php,v 1.24 2001/06/18 09:17:24 bzizou Exp $
Advanced functions menu

This script is part of the SLIS Project initiated by the CARMI-Internet
(Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet
(Acadmie de Grenoble - France 38).

This script have been writen by Bruno Bzeznik - copyright (C) 2001
Ce script  t crit par Bruno Bzeznik - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire.
Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License
along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail
to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  <slis@ac-grenoble.fr>
*/

// loading libs
require("../inc/html.inc.php");
require("../inc/lib.inc.php");

print startHTML("Advanced");

// The menu is different if there is only one network interface
if (n_interfaces() > 2) { $one_interface_menu=1;}

stop_if_no_admin();

// Prepare the menu
$text  = "<BR><FONT FACE=Helvetica,Arial>\n<UL><B>";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Administration</FONT>\n<UL>\n";
$text .= menu_item("../admin/administrator.php",$lang_adv_Admin_params,0,0);
$text .= menu_item("/cgi-bin/etrn.cgi",$lang_adv_Mailqueue,0,0);
$text .= menu_item("cancel.php?mode=view",$lang_adv_View,0,0);
$text .= menu_item("../admin/live_update.php",$lang_adv_Update,0,0);
$text .= menu_item("../admin/ups.php",$lang_adv_UPS,0,0);
if (file_exists("/etc/adsl")) {
  $text .= menu_item("../adsl/adsl-index.php",$lang_adv_ADSL,1,0);
}
if ($VTUN=="1") {
  $text .= menu_item("../admin/tunnel.php",$lang_adv_Tunnel,0,0);
}
$text .= menu_item("../admin/backup.php?action=wait",$lang_adv_Backup,0,0);
$text .= menu_item("../admin/shutdown.php",$lang_adv_Shutdown,0,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Web</FONT>\n<UL>\n";
$text .= menu_item("/cgi-bin/web_nom_webmaster_form.cgi",$lang_adv_Webmaster,0,0);
$text .= menu_item("../web/replication.php?action=index",$lang_adv_Push,0,0);
$text .= menu_item("../web/get.php?action=index",$lang_adv_Get,0,0);
$text .= menu_item("../baseweb.php",$lang_adv_DBweb,1,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Diags</FONT>\n<UL>\n";
$text .= menu_item("../diags/info.php",$lang_adv_Infos,0,0);
$text .= menu_item("../diags/stats.php?action=index",$lang_adv_Statsconn,0,0);
#$text .= menu_item("../prostat",$lang_adv_Proxy,0,0);
$text .= menu_item("../diags/ping.php",$lang_adv_Ping,0,0);
$text .= menu_item("../diags/df.php",$lang_adv_Disk,0,0);
$text .= menu_item("/cgi-bin/mail_watch_form.cgi",$lang_adv_Headers,0,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Secu</FONT>\n<UL>\n";
$text .= menu_item("/cgi-bin/subnets_act.cgi",$lang_adv_Access,0,1);
#$text .= menu_item("../secu/subnets.php",$lang_adv_Access,0,1);
$text .= menu_item("../secu/ip_filters.php",$lang_adv_IP_filters,0,1);
$text .= menu_item("/cgi-bin/squidguard_form.cgi",$lang_adv_URL_filters,0,0);
$text .= "</UL><P>\n";
$text .= "<LI><FONT SIZE=+1>$lang_adv_Lan</FONT>\n<UL>\n";
$text .= menu_item("../lan/vnc.php?action=index",$lang_adv_VNC,0,0);
$text .= menu_item("../dhcp",$lang_adv_DHCP,1,0);
$text .= "</B></UL><P></UL>\n";
if ($experimental_menu!=1) {
  $text .= "<HR><CENTER><A HREF=./advanced.php?experimental_menu=1>$lang_adv_Exp</A></CENTER><P>\n";
}
else {
  $text .= "<HR><CENTER><A HREF=./advanced.php?experimental_menu=0>$lang_adv_Normal</A></CENTER><P>\n";
  $exp=" <I>(experimental)</I>";
}
$text .= "</FONT><BR>\n";

// print the menu
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv . $exp,$titre_color);
$val = center($val);
$val = saut(2)."$val";
print "$val\n";      

// The end
print endHTML();

?>
